#define maxSize 500
#define maxW maxSize
#define maxH maxSize
#define maxN 2 * maxW * maxH - maxW - maxH

#include <stdio.h>

int w, h, n, i, x, y, total, mx;
int x0[maxN], y0[maxN], x1[maxN], y1[maxN], ans[maxN];
bool vertical[maxW][maxH], horizontal[maxH][maxW];
int search[maxW][maxH], sq_x[maxW * maxH], sq_y[maxW * maxH], sq_start, sq_end;
int parents[maxW * maxH], ranks[maxW * maxH];

inline int index(int x, int y)
{
    return y * w + x;
}

inline bool checkCell(int x, int y)
{
    return x >= 0 && y >= 0 && x < w && y < h && search[x][y] == -1;
}

inline void pushCell(int x, int y, int marker, int set)
{
    search[x][y] = marker;
    sq_x[sq_end] = x;
    sq_y[sq_end] = y;
    sq_end++;
    int ind = index(x, y);
    parents[ind] = set;
    if (ind != set)
        ranks[set] = 1;
}

inline void doSearch(int x, int y, int marker)
{
    int initial = index(x, y);
    sq_start = sq_end = 0;
    pushCell(x, y, marker, initial);
    while (sq_start < sq_end)
    {
        x = sq_x[sq_start];
        y = sq_y[sq_start];
        sq_start++;
        if (checkCell(x - 1, y) && ! vertical[x][y])
            pushCell(x - 1, y, marker, initial);
        if (checkCell(x, y - 1) && ! horizontal[y][x])
            pushCell(x, y - 1, marker, initial);
        if (checkCell(x + 1, y) && ! vertical[x + 1][y])
            pushCell(x + 1, y, marker, initial);
        if (checkCell(x, y + 1) && ! horizontal[y + 1][x])
            pushCell(x, y + 1, marker, initial);
    }
}

int find(int ind)
{
    if (parents[ind] != ind)
        parents[ind] = find(parents[ind]);
    return parents[ind];
}

inline void unite(int ind0, int ind1)
{
    int root0 = find(ind0);
    int root1 = find(ind1);
    if (root0 == root1)
        return;
    total--;
    if (ranks[root0] < ranks[root1])
        parents[root0] = root1;
    else if (ranks[root0] > ranks[root1])
        parents[root1] = root0;
    else
    {
        parents[root1] = root0;
        ranks[root0]++;
    }
}

inline void uncut_vertical(int x, int y)
{
    unite(index(x, y), index(x - 1, y));
}

inline void uncut_horizontal(int y, int x)
{
    unite(index(x, y), index(x, y - 1));
}

int main()
{
    //freopen("sheet.in", "r", stdin);
    //freopen("sheet.out", "w", stdout);

    scanf("%d%d%d", &w, &h, &n);

    for (x = 0; x < w; x++)
        for (y = 0; y < h; y++)
            vertical[x][y] = horizontal[y][x] = false;

    for (i = 0; i < n; i++)
    {
        scanf("%d%d%d%d", &x0[i], &y0[i], &x1[i], &y1[i]);
        if (x0[i] == x1[i])
            for (y = y0[i]; y < y1[i]; y++)
                vertical[x0[i]][y] = true;
        else
            for (x = x0[i]; x < x1[i]; x++)
                horizontal[y0[i]][x] = true;
    }

    for (i = 0, mx = w * h; i < mx; i++)
        ranks[i] = 0;
    total = 0;
    for (x = 0; x < w; x++)
        for (y = 0; y < h; y++)
            search[x][y] = -1;
    for (x = 0; x < w; x++)
        for (y = 0; y < h; y++)
            if (search[x][y] == -1)
            {
                doSearch(x, y, total);
                total++;
            }

    ans[n - 1] = total;
    for (i = n - 1; i > 0; i--)
    {
        if (x0[i] == x1[i])
            for (y = y0[i]; y < y1[i]; y++)
                uncut_vertical(x0[i], y);
        else
            for (x = x0[i]; x < x1[i]; x++)
                uncut_horizontal(y0[i], x);
        ans[i - 1] = total;
    }

    for (i = 0; i < n; i++)
        printf("%d\n", ans[i]);

    return 0;
}